__doc__ = """Question Product Module
             Built originally for the Survey Product"""
__version__ = 'v0.01'[1:]

from Globals import HTMLFile, MessageDialog, Persistent
from OFS.Folder import Folder
from OFS.SimpleItem import Item

class Question(Folder):
  """A Question for a Survey
  This may be extended to other classes later, such as quiz, test..."""
  meta_type = 'pmp_question'

  manage_options = (
    {'label':'Responses', 'action':'manage_responses'},
    {'label':'Properties', 'action':'manage_main'},
    {'label':'View', 'action':''},
    {'label':'Security', 'action':'manage_access'},
    )

  def __init__(self, id, question_text, option_type):
    """Initilization method for Question Class"""
    self.id = id
    self.question_text = question_text
    self.option_type = option_type
    self.answered = 0 
    self.times_answered = 0

  index_html = HTMLFile('question_index', globals())
  manage_responses = HTMLFile('surveyResponsesEdit', globals())
  manage_main = HTMLFile('surveyQuestionEdit', globals())

  def manage_edit(self, title, question_text, option_type, REQUEST=None):
    """Change properties for the Question Instance"""
    self.title = title
    self.question_text = question_text
    self.option_type = option_type
    if REQUEST is not None:
      return MessageDialog(
        title = 'Edited',
        message = 'Properties for %s changed' % self.id,
        action = './manage_main',
        )

  def createUniqueResponseId(self):
    """Method to create unique Response Id"""
    responseNumber = 1
    currentIds = self.objectIds(['pmp_response'])
    while 1:
      newResponseId = "response%s" % responseNumber
      if not newResponseId in currentIds:
        break
      responseNumber = responseNumber + 1
    return newResponseId

  def manage_addResponse(self, option_text = '', REQUEST = None):
    """Add Response Instance to a Question Instance"""
    if option_text is not '':
      newResponseId = self.createUniqueResponseId()
      newResponse = Response(newResponseId, option_text)
      self._setObject(newResponseId, newResponse)
    return self.manage_responses(self, REQUEST)

  def manage_preDelete(self, ids=[], REQUEST=None):
    """Check to see if there is input..."""
    if not ids:
      return MessageDialog(
        title='No items specified',
        message='No items were specified!',
        action='./manage_responses',)
    else:
      return self.manage_delObjects(ids, REQUEST=REQUEST)

class Response(Item):
  """Response entry for a questions.
  Having this as a seperate class allows Question to have
  any number of instances of the Response item..."""
  meta_type = 'pmp_response'

  manage_options = (
    {'label':'Properties', 'action':'manage_main'},
    {'label':'View', 'action':''},
    )

  def __init__(self, id, option_text):
    """Initialization method for Response Class"""
    self.id = id
    self.option_text = option_text
    self.times_chosen = 0

  index_html = HTMLFile('response_index', globals())
  manage_main = HTMLFile('surveyResponseEdit', globals())

