__doc__ = """Survey Product Module"""
__version__ = 'v0.1.0'[1:]

from Question import *
from Globals import HTMLFile, MessageDialog, Persistent, package_home
from OFS.Folder import Folder
from OFS.DTMLMethod import DTMLMethod

import Acquisition
import os

manage_addSurveyForm = HTMLFile('surveyAddForm', globals())

def manage_addSurvey(self, id, title='', survey_text = '', follow = './index_html', REQUEST=None):
  """Add a survey to the current folder"""
  self._setObject(id, Survey(id, title, survey_text, follow))
  if REQUEST is not None:
    return self.manage_main(self, REQUEST)

class Survey(Folder, Acquisition.Implicit):
  meta_type = 'pmp_survey'
  

  manage_options = (
    {'label':'Questions', 'action':'manage_questions'}, 
    {'label':'Properties', 'action':'manage_main'},
    {'label':'Methods', 'action':'manage_documents'},
    {'label':'View', 'action':''},
    {'label':'Security', 'action':'manage_access'},
    )
	
  __ac_permissions__ = (
    ('View management screens', ('manage_tabs', 'manage_main')),
    ('Change permissions', ('manage_access',)),
    ('Change Surveys', ('manage_edit', 'manage_questions')),
    ('Respond to Survey', ('manage_updateFromPost',)),
    ('View', ('',)),
    )
	
  def __init__(self, id, title = '', survey_text = '', follow = './index_html'):
    """Initialization function for Survey Class"""
    self.id = id
    self.title = title
    self.survey_text = survey_text
    self.followup = follow

    prefix = package_home(globals())

    fileName = os.path.join(prefix, 'index.dtml')
    index = open(fileName, 'r').read()
    i = DTMLMethod(index, __name__='index_html')
    i.title = title
    self._setObject('index_html', i)

    fileName = os.path.join(prefix, 'render.dtml')
    index = open(fileName, 'r').read()
    i = DTMLMethod(index, __name__='render_html')
    i.title = title
    self._setObject('render_html', i)

  manage_documents=HTMLFile('surveyMethods', globals())
  manage_questions = HTMLFile('surveyQuestionsEdit', globals()) 
  manage_main = HTMLFile('surveyEdit', globals())

  def manage_edit(self, title, survey_text, follow, REQUEST=None):
    """Survey Properties Edit function"""
    self.title = title
    self.survey_text = survey_text
    self.followup = follow
    if REQUEST is not None:
      return MessageDialog(
        title = 'Edited',
	message = "Properties for %s changed." % self.id,
	action = './manage_main',
	)

  def createUniqueQuestionId(self):
    """Method to create Unique Question Id"""
    questionNumber = 1
    currentIds = self.objectIds(['pmp_question'])
    while 1:
      newQuestionId = "question%s" % questionNumber
      if not newQuestionId in currentIds:  
        break
      questionNumber = questionNumber + 1
    return newQuestionId
	
  def manage_addQuestion(self, question_text = '', option_type = '', REQUEST = None):
    """Add a question to this survey
    This requires the question class to be available."""
    if question_text is not '': 
      newQuestionId = self.createUniqueQuestionId()
      newQuestion = Question(newQuestionId, question_text, option_type)
      self._setObject(newQuestionId, newQuestion)
    return self.manage_questions(self, REQUEST)

  def manage_preDelete(self, ids=[], REQUEST=None):
    """Check to see if there is input..."""
    if not ids:
      return MessageDialog(
        title='No items specified',
        message='No items were specified!',
        action='./manage_questions',)
    else:
      return self.manage_delObjects(ids, REQUEST=REQUEST)

  def manage_updateFromPost(self, idWords=[], REQUEST=None):
    """Update Question and Response data based on form input..."""
    if not idWords:                                               
      return MessageDialog(
        title='No response specified',
        message='No response were specified!',
        action=self.followup)               
    else:
      questionValues = self.objectValues(['pmp_question'])
      for i in idWords:                                
        for q in questionValues:
          responseValues = q.objectValues(['pmp_response'])
          for r in responseValues:                                 
            if i == q.id + '_' + r.id:
              r.times_chosen = r.times_chosen + 1
              if q.answered == 0:                              
                q.answered = 1 
                q.times_answered = q.times_answered + 1
      for q in questionValues:                                            
        q.answered = 0 
      return MessageDialog(
        title='Responses Accepted',
        message='Your responses were accepted and recorded.',
        action=self.followup)
